package com.softweb.iotconnectdemo;


import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.Toast;

import com.iotconnectsdk.IoTConnectSDK;
import com.iotconnectsdk.interfaces.IotSDKCallback;
import com.iotconnectsdk.webservices.responsebean.HubToSdkDataBean;
import com.iotconnectsdk.webservices.responsebean.SyncServiceResponse;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

import static com.iotconnectsdk.utils.IotSDKConstant.CORE_COMMAND;
import static com.iotconnectsdk.utils.IotSDKConstant.FIRMWARE_UPDATE;

public class IOTConnect_SDK_Sample extends AppCompatActivity implements IotSDKCallback {

    IoTConnectSDK iotConnect;// = new IoTConnectSDK();

    String  cpId = "";//<< CPID >>";
    String uniqueId = "";//"<< Device UniqueID >>";
    String env = "";//"<< Environment >>";
    public static String getCurrentTime() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSS'Z'");
        return sdf.format(new Date());
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
		
		iotConnect = new IoTConnectSDK(IOTConnect_SDK_Sample.this,cpId, uniqueId,
                IOTConnect_SDK_Sample.this, env);

        Button btnSendData = (Button) findViewById(R.id.btnSendData);
        btnSendData.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if(checkValidation())
                {  
			
					String sendTeledata = "[{\"uniqueId\":\"\",\"time\" : \"2020-09-17T10:06:17.857Z\"," +
                            "\"data\": {\"Temp\": 15.55,\"humidity\" : 27.97,\"Gyroscope\" : {\"x\": -1.2,\"y\" : 0.25,\"z\" : 1.1}}}]";

                        if (iotConnect != null) {
                            iotConnect.sendData(sendTeledata);
                            Log.e("json", "" + sendTeledata);
                            Toast.makeText(IOTConnect_SDK_Sample.this, "Data Sent", Toast.LENGTH_SHORT).show();
                        }

                }
            }
        });

       
    }

    private boolean checkValidation() {
        if (cpId.isEmpty()) {
            Toast.makeText(IOTConnect_SDK_Sample.this, "cpId can not be blank.", Toast.LENGTH_LONG).show();
            return false;
        } else if (uniqueId.isEmpty()) {
            Toast.makeText(IOTConnect_SDK_Sample.this, "uniqueId can not be blank.", Toast.LENGTH_LONG).show();
            return false;
        }else if (env.isEmpty()) {
            Toast.makeText(IOTConnect_SDK_Sample.this, "env can not be blank.", Toast.LENGTH_LONG).show();
            return false;
        }
        return true;
    }


    @Override
    public void onReceiveMsg(String message) {
        if (!message.isEmpty()) {
            int st;
            String messageType, uniqueId, ackId, cpId;

            try {
                JSONObject mainObject = new JSONObject(message);
                String cmdType = mainObject.getString("cmdType");
                JSONObject dataObj = mainObject.getJSONObject("data");
                ackId = dataObj.getString("ackId");

                JSONArray urlArry = dataObj.getJSONArray("urls");
                JSONObject urlObj = urlArry.getJSONObject(0);

                switch (cmdType) {
                    case CORE_COMMAND:
                        if (ackId != null && !ackId.isEmpty()) {
                            messageType = "5";
                            JSONObject objD = getAckObject(mainObject);
                            objD.put("st", 6);
                            iotConnect.sendAck(objD, messageType);
                        }
                        break;
                    case FIRMWARE_UPDATE:
                        if (ackId != null && !ackId.isEmpty()) {
                            messageType = "11";
                            JSONObject obj = getAckObject(mainObject);
                            obj.put("st", 7);
                            iotConnect.sendAck(obj, messageType);
                        }
                        break;
                    default:
                        break;
                }

            } catch (JSONException e) {
                e.printStackTrace();
            }
        }
    }

    @Override
    public void attributeData(List<SyncServiceResponse.DBeanXX.AttBean> attributesBeanList) {

    }

    private JSONObject getAckObject(JSONObject mainObject) {

        JSONObject objD = null;
        String childId = "";
        try {
            JSONObject dataObj = mainObject.getJSONObject("data");
            String ackId = dataObj.getString("ackId");
            try {
                if (dataObj.has("urls")) {
                    JSONArray urlsObj = dataObj.getJSONArray("urls");
                    JSONObject arObject = (JSONObject) urlsObj.get(0);
                    if (arObject.has("uniqueId"))
                        childId = arObject.getString("uniqueId");
                }
            } catch (JSONException e) {
                e.printStackTrace();
            }
            //create json object.
            objD = new JSONObject();
            objD.put("ackId", ackId);
            objD.put("msg", "OTA updated successfully..!!");
            objD.put("childId", childId);
        } catch (JSONException e) {
            e.printStackTrace();
        }

        return objD;
    }

    @Override
    public void onConnectionStateChange(boolean isConnected) {
        if (isConnected) {
            Log.e("onConnectionStateChange", "Device connected");
        } else {
            Log.e("onConnectionStateChange", "Device disconnected");
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (iotConnect != null) {
            iotConnect.disconnectSDK();
        }
    }

    @Override
    public void onPointerCaptureChanged(boolean hasCapture) {

    }
}
